from setuptools import setup, find_packages
setup()

# setup(
#     name="pyconfigevents",
#     version="0.1.1",  # Update with your version
#     packages=find_packages(),
#     install_requires=[
#         "pydantic>=2.11.4",
#         "pytomlpp>=1.0.13",
#         "pyyaml>=6.0.2",
#     ],
#     python_requires=">=3.12",
# )